VisCoSo

## Problem

Root problem

Universe

squares | r2 | b2
(triangles) ∧ (¬green) | r1 | b1
green | green | green | green

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green, green};
    property squares = {r2, b2};
    property (triangles) ∧ (¬green) = {r1, b1};
    property green = {green, green, green};

Configuration

1
1 | 2
1 | 2 | 3
1 | 2 | 3 | 4

CoLa

    permutation (size in [1,4]) of entity universe (perm)

Constraints

2 |  |  | green

CoLa

    Position 2: green;
    Nr. squares in [2, 7];

20

0

Configuration of size 1

Universe

squares | r2 | b2
(triangles) ∧ (¬green) | r1 | b1
green | green | green | green

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green, green};
    property squares = {r2, b2};
    property (triangles) ∧ (¬green) = {r1, b1};
    property green = {green, green, green};

Configuration

1

CoLa

    Obj 1:  (squares) ∨ (triangles);

Constraints

2 |  |  | green

CoLa

    Position 2: green;
    Nr. squares in [2, 7];

0

$$\texttip{ 0 }{ Cannot satisfy Nr. squares in [2, 7] :( }$$

0

Configuration of size 2

Universe

green | green | green | green
(triangles) ∧ (¬green) | r1 | b1
squares | r2 | b2

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green, green};
    property green = {green, green, green};
    property (triangles) ∧ (¬green) = {r1, b1};
    property squares = {r2, b2};

Configuration

1 | 2

CoLa

    Obj 1:  (squares) ∨ (triangles);
    Obj 2:  (squares) ∨ (triangles);

Constraints

2 |  |  | green

CoLa

    Position 2: green;
    Nr. squares in [2, 7];

0

$$\texttip{ 0 }{ No solution found }$$

2

Configuration of size 3

Universe

(triangles) ∧ (¬green) | r1 | b1
squares | r2 | b2
green | green | green | green

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green, green};
    property (triangles) ∧ (¬green) = {r1, b1};
    property squares = {r2, b2};
    property green = {green, green, green};

Configuration

1 | 2 | 3

CoLa

    Obj 1:  (squares) ∨ (triangles);
    Obj 2:  (squares) ∨ (triangles);
    Obj 3:  (squares) ∨ (triangles);

Constraints

2 |  |  | green

CoLa

    Position 2: green;
    Nr. squares in [2, 7];

2

1

Left split: case 1 green are s.t. [Nr. squares = 0, Nr. green = 1, Nr. ¬green = 0]

Universe

squares | r2 | b2
(triangles) ∧ (¬green) | r1 | b1
green | green | green | green

CoLa

    universe green = {green, green, green};
    property squares = {r2, b2};
    property (triangles) ∧ (¬green) = {r1, b1};

Configuration

1

CoLa

    Obj 1:  green;

Constraints

CoLa

    Nr. squares = 0;
    Nr. green = 1;
    Nr. ¬green = 0;

1

$$\frac{\texttip{ \binom{ 0 }{ 0 } }{ Choose 0 of 0 (distinguishable) empty for 1 object(s) } \cdot \texttip{ 1! }{ Permutations of 1 green }}{\texttip{ 1! }{ Extra permutations of (indist.) green }}$$

2

Right split removing 1 green

Universe

squares | r2 | b2
triangles | r1 | b1 | green | green | green
|  |  |  |  | 5

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green};
    property squares = {r2, b2};
    property triangles = {r1, b1, green, green, green};

Configuration

1 | 2

CoLa

    Obj 1:  (squares) ∨ (triangles);
    Obj 2:  (squares) ∨ (triangles);

Constraints

CoLa

    Nr. squares = 2;

2

$$\texttip{ \texttip{ 1 }{ Exchangeable choices } \cdot 2! }{ Nr. orders for all objects }$$

18

Configuration of size 4

Universe

(triangles) ∧ (¬green) | r1 | b1
squares | r2 | b2
green | green | green | green

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green, green};
    property (triangles) ∧ (¬green) = {r1, b1};
    property squares = {r2, b2};
    property green = {green, green, green};

Configuration

1 | 2 | 3 | 4

CoLa

    Obj 1:  (squares) ∨ (triangles);
    Obj 2:  (squares) ∨ (triangles);
    Obj 3:  (squares) ∨ (triangles);
    Obj 4:  (squares) ∨ (triangles);

Constraints

2 |  |  | green

CoLa

    Position 2: green;
    Nr. squares in [2, 7];

18

1

Left split: case 1 green are s.t. [Nr. squares = 0, Nr. green = 1, Nr. ¬green = 0]

Universe

squares | r2 | b2
(triangles) ∧ (¬green) | r1 | b1
green | green | green | green

CoLa

    universe green = {green, green, green};
    property squares = {r2, b2};
    property (triangles) ∧ (¬green) = {r1, b1};

Configuration

1

CoLa

    Obj 1:  green;

Constraints

CoLa

    Nr. squares = 0;
    Nr. green = 1;
    Nr. ¬green = 0;

1

$$\frac{\texttip{ \binom{ 0 }{ 0 } }{ Choose 0 of 0 (distinguishable) empty for 1 object(s) } \cdot \texttip{ 1! }{ Permutations of 1 green }}{\texttip{ 1! }{ Extra permutations of (indist.) green }}$$

18

Right split removing 1 green

Universe

squares | r2 | b2
triangles | r1 | b1 | green | green | green
|  |  |  |  | 5

CoLa

    universe (squares) ∨ (triangles) = {r2, b2, r1, b1, green, green};
    property squares = {r2, b2};
    property triangles = {r1, b1, green, green, green};

Configuration

1 | 2 | 3

CoLa

    Obj 1:  (squares) ∨ (triangles);
    Obj 2:  (squares) ∨ (triangles);
    Obj 3:  (squares) ∨ (triangles);

Constraints

CoLa

    Nr. squares in [2, 3];

18

2

Left split: case 2 squares are s.t. [Nr. squares = 2]

Universe

squares | r2 | b2
triangles | r1 | b1 | green | green | green
|  |  |  |  | 5

CoLa

    universe squares = {r2, b2};
    property triangles = {r1, b1, green, green, green};

Configuration

1 | 2

CoLa

    Obj 1:  squares;
    Obj 2:  squares;

Constraints

CoLa

    Nr. squares = 2;

2

$$\texttip{ 2! }{ Nr. orders for all objects }$$

3

Right split removing 2 squares

Universe

(squares) ∨ (triangles) | r1 | b1 | green | green

CoLa

    universe (squares) ∨ (triangles) = {r1, b1, green, green};

Configuration

1

CoLa

    Obj 1:  (squares) ∨ (triangles);

3

$$\frac{\texttip{ \binom{ 2 }{ 0 } }{ Choose 0 of 2 (distinguishable) ??? for 1 object(s) } \cdot \texttip{ 1! }{ Permutations of 1 (squares) ∨ (triangles) }}{\texttip{ 1! }{ Extra permutations of (indist.) ??? }} + \frac{\texttip{ \binom{ 2 }{ 1 } }{ Choose 1 of 2 (distinguishable) ??? for 1 object(s) } \cdot \texttip{ 1! }{ Permutations of 1 (squares) ∨ (triangles) }}{\texttip{ 0! }{ Extra permutations of (indist.) ??? }}$$